@@ -1,26 +1,34 @@
+
+"""
+.. module:: procfs.cli
+  :synopsis: procfs command line interface
+  :platform: Unix
+.. moduleauthor:: Robert Xu <robxu9@gmail.com>
+.. moduleauthor:: Jeff Lindsay <progrium@gmail.com>
+
+"""
+
 import argparse
 import json
-import os
 import sys
-import string
 
 from datetime import timedelta
 
 from procfs import Proc
 from procfs.core import ProcDirectory
 from procfs.core import ProcessDirectory
-from procfs.core import ProcessFile
-from procfs.core import File
 
-from procfs.exceptions import DoesNotExist
+from procfs.exceptions import PathNotFoundError
+
 
 class CustomEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, timedelta):
-            return ((obj.microseconds + 
+            return ((obj.microseconds +
                      (obj.seconds + obj.days * 24 * 3600) * 10**6) // 10**6)
         return json.JSONEncoder.default(self, obj)
 
+
 def find(path, list):
     obj = Proc()
 
@@ -30,24 +38,27 @@ def find(path, list):
             continue
         try:
             obj = obj.__getattr__(v)
-        except (KeyError, DoesNotExist, AttributeError) as e:
+        except (KeyError, PathNotFoundError, AttributeError) as e:
             try:
                 obj = obj.__getattr__(int(v))
-            except (KeyError, ValueError, DoesNotExist, AttributeError) as e:
+            except (KeyError, ValueError,
+                    PathNotFoundError, AttributeError) as e:
                 try:
                     obj = obj.__getitem__(v)
-                except (KeyError, DoesNotExist, AttributeError) as e:
+                except (KeyError, PathNotFoundError, AttributeError) as e:
                     try:
                         obj = obj.__getitem__(int(v))
-                    except (KeyError, ValueError, DoesNotExist, AttributeError) as e:
-                        raise DoesNotExist(path)
+                    except (KeyError, ValueError,
+                            PathNotFoundError, AttributeError) as e:
+                        raise PathNotFoundError(path)
         if callable(obj):
             obj = obj()
 
     if list:
         if isinstance(obj, dict):
             return json.dumps(obj.keys(), cls=CustomEncoder)
-        elif isinstance(obj, ProcDirectory) or isinstance(obj, ProcessDirectory):
+        elif isinstance(obj, ProcDirectory) \
+                or isinstance(obj, ProcessDirectory):
             keys = []
             for key in obj.__dir__():
                 keys.append(key)
@@ -62,15 +73,18 @@ def find(path, list):
         obj = keys
     return json.dumps(obj, cls=CustomEncoder)
 
+
 def run():
     parser = argparse.ArgumentParser()
-    parser.add_argument('path', metavar='PATH', type=str, nargs='?', default="", help='procfs path')
-    parser.add_argument('-l', '--list', help='list all available keys', action='store_true')
+    parser.add_argument('path', metavar='PATH', type=str, nargs='?',
+                        default="", help='procfs path')
+    parser.add_argument('-l', '--list', help='list all available keys',
+                        action='store_true')
     args = parser.parse_args()
 
     try:
         print find(args.path, args.list)
-    except DoesNotExist as e:
+    except PathNotFoundError as e:
         print "couldn't find path %s" % e
         sys.exit(1)
     except AttributeError as e:
